import{a as r,b as h}from"./chunk-XEEMGNQM.js";import"./chunk-7OZEUT5F.js";import{a as o,b as p}from"./chunk-MQXJYUPY.js";import"./chunk-OETKJM3Q.js";import"./chunk-6WF6MHOA.js";import"./chunk-SADKIAAT.js";import"./chunk-YINSOKTV.js";import{a as t,b as e}from"./chunk-UMW5WEDH.js";import"./chunk-KU6HOEJ6.js";import"./chunk-V7KIDDHO.js";import"./chunk-Y3GTLAV4.js";import"./chunk-6CVIMIXX.js";import"./chunk-JZUJMEFG.js";import"./chunk-E3SZKR6M.js";import"./chunk-BXBF54ET.js";import"./chunk-5DATZV72.js";import"./chunk-3RHWAFOM.js";import"./chunk-LG3SCC2E.js";import"./chunk-R2ULAEP2.js";import"./chunk-ZSHAELBT.js";import"./chunk-UGQXGBKF.js";import"./chunk-TCUK52QT.js";import"./chunk-KRM6VGUP.js";import"./chunk-AFLM5QFV.js";import"./chunk-DCQJQBJ7.js";import"./chunk-VYRWAFSM.js";import"./chunk-QV5EZVUU.js";import"./chunk-232C3GE4.js";import"./chunk-WHHOASZ7.js";import"./chunk-LFKM2JDJ.js";import"./chunk-AI3O53K7.js";import"./chunk-QQZCALHS.js";import"./chunk-NIOUKWEO.js";import"./chunk-B27RXKCZ.js";import"./chunk-7HVZ3SHK.js";import"./chunk-HW6LKGMV.js";import"./chunk-XRGTMJIH.js";import"./chunk-SROICVCU.js";import"./chunk-V3J5YJ3L.js";import"./chunk-UIVS6623.js";import"./chunk-2XIOYYFS.js";import"./chunk-HYPRVELK.js";import"./chunk-YTY7HHO3.js";import"./chunk-UOI75ONS.js";import"./chunk-4HFZZ7HS.js";import{e as m}from"./chunk-SZAW6ZBW.js";var s,i=m(()=>{e();p();h();s=[{canActivate:[t,o],providers:[r],path:"",pathMatch:"full",loadComponent:()=>import("./chunk-VVAI4LCV.js").then(a=>a.SystemDashboardComponent)}]});i();export{s as SYSDASHBOARD_ROUTES};
