import{a as n,b as e}from"./chunk-UMW5WEDH.js";import"./chunk-KU6HOEJ6.js";import"./chunk-QV5EZVUU.js";import"./chunk-232C3GE4.js";import"./chunk-WHHOASZ7.js";import"./chunk-AI3O53K7.js";import"./chunk-QQZCALHS.js";import"./chunk-NIOUKWEO.js";import"./chunk-B27RXKCZ.js";import"./chunk-7HVZ3SHK.js";import"./chunk-HW6LKGMV.js";import"./chunk-SROICVCU.js";import"./chunk-V3J5YJ3L.js";import"./chunk-UIVS6623.js";import"./chunk-2XIOYYFS.js";import"./chunk-HYPRVELK.js";import"./chunk-YTY7HHO3.js";import"./chunk-UOI75ONS.js";import"./chunk-4HFZZ7HS.js";import{e as t}from"./chunk-SZAW6ZBW.js";var m,p=t(()=>{e();m=[{path:":repositoryId/:connectionId",canActivate:[n],loadComponent:()=>import("./chunk-5QRKK4LJ.js").then(o=>o.WebClientComponent),children:[{path:":sessionId",loadComponent:()=>import("./chunk-6K2NLBGL.js").then(o=>o.WebClientPlaceholderComponent)},{path:"ard",loadComponent:()=>import("./chunk-COK7R2BC.js").then(o=>o.WebClientArdComponent)},{path:"rdp",loadComponent:()=>import("./chunk-EKFHWEWH.js").then(o=>o.WebClientRdpComponent)},{path:"vnc",loadComponent:()=>import("./chunk-UBKEFUOQ.js").then(o=>o.WebClientVncComponent)},{path:"ssh",loadComponent:()=>import("./chunk-ATKQZSYS.js").then(o=>o.WebClientSshShellComponent)},{path:"telnet",loadComponent:()=>import("./chunk-AXLQ4R7B.js").then(o=>o.WebClientTelnetComponent)},{path:"powershell",loadComponent:()=>import("./chunk-XTMTF7PC.js").then(o=>o.WebClientPowerShellComponent)}]}]});p();export{m as WEB_CLIENT_ROUTES};
