import{a as o,b as n}from"./chunk-32OHELOG.js";import{a as t,b as m}from"./chunk-UMW5WEDH.js";import"./chunk-KU6HOEJ6.js";import"./chunk-QV5EZVUU.js";import"./chunk-232C3GE4.js";import"./chunk-WHHOASZ7.js";import"./chunk-AI3O53K7.js";import"./chunk-QQZCALHS.js";import"./chunk-NIOUKWEO.js";import"./chunk-B27RXKCZ.js";import"./chunk-7HVZ3SHK.js";import"./chunk-HW6LKGMV.js";import"./chunk-SROICVCU.js";import"./chunk-V3J5YJ3L.js";import"./chunk-UIVS6623.js";import"./chunk-2XIOYYFS.js";import"./chunk-HYPRVELK.js";import"./chunk-YTY7HHO3.js";import"./chunk-UOI75ONS.js";import"./chunk-4HFZZ7HS.js";import{e as a}from"./chunk-SZAW6ZBW.js";var i,p=a(()=>{m();n();i=[{path:"",canActivate:[t,o],children:[{path:"",loadComponent:()=>import("./chunk-QFLXYEZZ.js").then(r=>r.CheckoutListComponent)}]}]});p();export{i as CHECKOUT_ROUTES};
