import{a as n,c as s}from"./chunk-YHBMN7V6.js";import{a as t,b as r}from"./chunk-UMW5WEDH.js";import"./chunk-KU6HOEJ6.js";import"./chunk-ZSHAELBT.js";import"./chunk-QV5EZVUU.js";import"./chunk-232C3GE4.js";import"./chunk-WHHOASZ7.js";import"./chunk-AI3O53K7.js";import"./chunk-QQZCALHS.js";import"./chunk-NIOUKWEO.js";import"./chunk-B27RXKCZ.js";import"./chunk-7HVZ3SHK.js";import"./chunk-HW6LKGMV.js";import{Yb as i,Zb as e}from"./chunk-SROICVCU.js";import"./chunk-V3J5YJ3L.js";import"./chunk-UIVS6623.js";import"./chunk-2XIOYYFS.js";import"./chunk-HYPRVELK.js";import"./chunk-YTY7HHO3.js";import"./chunk-UOI75ONS.js";import"./chunk-4HFZZ7HS.js";import{e as a}from"./chunk-SZAW6ZBW.js";var h,p=a(()=>{r();s();e();h=[{path:"",canActivate:[t],loadComponent:()=>import("./chunk-MBFS4Z5Y.js").then(o=>o.NotificationsComponent),children:[{path:"user-subscriptions",canActivate:[t,n],data:{permissions:[i.NotificationsUserView]},loadComponent:()=>import("./chunk-MAMRH5O7.js").then(o=>o.UserSubscriptionDashboardComponent)},{path:"subscriptions",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriptionsView]},loadComponent:()=>import("./chunk-GC2DETTO.js").then(o=>o.SubscriptionDashboardComponent)},{path:"groups",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriberGroupView]},loadComponent:()=>import("./chunk-OEWQ64DU.js").then(o=>o.SubscriberGroupDashboardComponent)},{path:"subscribers",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriberView]},loadComponent:()=>import("./chunk-VRLVMIPN.js").then(o=>o.SubscriberDashboardComponent)},{path:"notification-preferences-dashboard",loadComponent:()=>import("./chunk-QEVZ76FX.js").then(o=>o.NotificationPreferencesDashboardComponent)},{path:"",loadComponent:()=>import("./chunk-6Q2XOPQB.js").then(o=>o.NotificationsDashboardComponent)}]}]});p();export{h as NOTIFICATIONS_ROUTES};
