import{a as o,b as p}from"./chunk-32OHELOG.js";import{a as m,c as s}from"./chunk-YHBMN7V6.js";import{a as i,b as n}from"./chunk-UMW5WEDH.js";import"./chunk-KU6HOEJ6.js";import"./chunk-ZSHAELBT.js";import"./chunk-QV5EZVUU.js";import"./chunk-232C3GE4.js";import"./chunk-WHHOASZ7.js";import"./chunk-AI3O53K7.js";import"./chunk-QQZCALHS.js";import"./chunk-NIOUKWEO.js";import"./chunk-B27RXKCZ.js";import"./chunk-7HVZ3SHK.js";import"./chunk-HW6LKGMV.js";import{Yb as t,Zb as e}from"./chunk-SROICVCU.js";import"./chunk-V3J5YJ3L.js";import"./chunk-UIVS6623.js";import"./chunk-2XIOYYFS.js";import"./chunk-HYPRVELK.js";import"./chunk-YTY7HHO3.js";import"./chunk-UOI75ONS.js";import"./chunk-4HFZZ7HS.js";import{e as a}from"./chunk-SZAW6ZBW.js";var A,d=a(()=>{n();p();s();e();A=[{path:"",children:[{path:"",canActivate:[i,o,m],data:{permissions:[t.PamSettingsJitTemplatesView]},loadComponent:()=>import("./chunk-AYFBHO3Q.js").then(r=>r.SshJitTemplatesDashboardComponent)}]}]});d();export{A as SSH_JIT_TEMPLATES_ROUTES};
