import{a as l,b}from"./chunk-B27RXKCZ.js";import{T as f,U as C}from"./chunk-7HVZ3SHK.js";import{Wj as p,Xj as A}from"./chunk-SROICVCU.js";import{g as m,h as j}from"./chunk-V3J5YJ3L.js";import{b as n,c as d}from"./chunk-YTY7HHO3.js";import{Rd as S,ka as a,na as v,sa as c,x as o,xa as r}from"./chunk-4HFZZ7HS.js";import{e as u}from"./chunk-SZAW6ZBW.js";var w,g=u(()=>{v();b();S();A();C();d();j();w=(()=>{class t extends l{constructor(s,i,e,h){super(e,h,i),this.assetServices=s}getAllRoleSummaries(s=!1){let i=this.assetServices.GetRolesBasic().pipe(a(e=>this.handleGetApiResult(e)),o(e=>this.returnWhenSuccessful(e,()=>e.data)));return this.getCache(s,i)}static{this.\u0275fac=function(i){return new(i||t)(r(p),r(f),r(n),r(m))}}static{this.\u0275prov=c({token:t,factory:t.\u0275fac,providedIn:"root"})}}return t})()});export{w as a,g as b};
